********************************************************************************
*
*     A Comparative Analysis of Contract and Government  
* 	  Teachers in Sierra Leone: Profiles and Practices 
*
*     Stata .do file 2: Cleaning
*
********************************************************************************

clear all
set more off
set mem 100m

***************************************
* GEPD Teacher and School Datasets
***************************************

**** Merging datasets 

use "$rawdata/GEPD_school_country_level.dta"
drop if country!="SLE"
keep school_code hashed_school_code
save "$cleandata/GEPD_country_var.dta", replace // removing all countries except Sierra Leone from the school level dataset

use "$rawdata/GEPD_weights.dta"
drop if iso3c!="SLE"
save "$cleandata/GEPD_teacher_weights.dta", replace // removing all countries except Sierra Leone from the teacher weights dataset

use "$rawdata/GEPD_teacher_school_country_level.dta"
drop if country!="SLE"
save "$cleandata/GEPD_teacher_level.dta", replace // removing all countries except Sierra Leone from the teacher level dataset

use "$rawdata/GEPD_g4student_teacher_school_country_level.dta"
drop if country!="SLE"
drop if s_0_1_1==.
keep hashed_school_code school_code student_age student_male literacy_student_knowledge literacy_student_proficient math_student_knowledge student_knowledge math_student_proficient fourth_grade_assessment_id
save "$cleandata/GEPD_student.dta", replace // removing all countries except Sierra Leone from the student level dataset

use "$cleandata/GEPD_teacher_weights.dta"
merge 1:m hashed_school_code using "$cleandata/GEPD_teacher_level.dta"
drop _merge
duplicates report hashed_school_code teachers_id
duplicates drop hashed_school_code teachers_id, force
merge m:1 hashed_school_code using "$cleandata/GEPD_country_var.dta" // merging all three datasets

save "$cleandata/GEPD_clean.dta", replace

*** Formatting variables

use "$cleandata/GEPD_clean.dta"

** Renaming variables for ease of reading 
rename m2saq3 gender
rename m3saq6 age
rename m3saq4 edu_level
rename m2saq6 fulltime 
rename m2sbq6_efft teacher_absent

** Converting/creating variables to make running the analysis easier (school level)

* Region 
drop region
gen region=1 if idregion=="EASTERN"
replace region=2 if idregion=="NORTH WESTERN"
replace region=3 if idregion=="NORTHERN"
replace region=4 if idregion=="SOUTHERN"
replace region=5 if idregion=="WESTERN"
label define region 1 "Eastern" 2 "North Western" 3 "Northern" 4 "Southern" 5 "Western"
label value region region 
label var region "Region"

* District
drop district
gen district=1 if iddistrict=="BO"
replace district=2 if iddistrict=="BOMBALI"
replace district=3 if iddistrict=="BONTHE"
replace district=4 if iddistrict=="FALABA"
replace district=5 if iddistrict=="KAILAHUN"
replace district=6 if iddistrict=="KAMBIA"
replace district=7 if iddistrict=="KARENE"
replace district=8 if iddistrict=="KENEMA"
replace district=9 if iddistrict=="KOINADUGU"
replace district=10 if iddistrict=="KONO"
replace district=11 if iddistrict=="MOYAMBA"
replace district=12 if iddistrict=="PORT LOKO"
replace district=13 if iddistrict=="PUJEHUN"
replace district=14 if iddistrict=="TONKOLILI"
replace district=15 if iddistrict=="WESTERN AREA RURAL"
replace district=16 if iddistrict=="WESTERN AREA URBAN"
label define district 1	"Bo"	2	"Bombali"	3	"Bonthe"	4	"Falaba"	5	"Kailahun"	6	"Kambia"	7	"Karene"	8	"Kenema"	9	"Koinadugu"	10	"Kono"	11	"Moyamba"	12	"Port Loko"	13	"Pujehun"	14	"Tonkolili"	15	"Western Area Rural"	16	"Western Area Urban"
label value district district
label var district "District"

* Urban vs rural school location
gen urban_rural1=0 if urban_rural=="Rural"
replace urban_rural1=1 if urban_rural=="Urban"
label define urban_rural1 0 "Rural" 1 "Urban"
label value urban_rural1 urban_rural1
drop urban_rural
rename urban_rural1 urban_rural
label var urban_rural "Urban or Rural"

** Converting/creating variables to make running the analysis easier (teacher level)

* Teacher variable 
gen teacher=0
replace teacher=1 if m2saq4==3 | m2saq4_other=="Volunteer" | m2saq4_other=="Community Teacher"
replace teacher=. if missing(m2saq4)
label define teacher 0 "No" 1 "Yes"
label value teacher teacher
label var teacher "Classroom Teacher"

* Government or contract teacher variable
gen government=0 
replace government=1 if (m2saq5==1 | m2saq5==6) & teacher==1
replace government=. if missing(m2saq5)
label define government 0 "Non-Govt" 1 "Govt"
label value government government
label var government "Government or Non-Government Teacher"
drop if government==.

* Years of experience teacher variable
gen service_years = 2022 - m3saq5

gen years=.
replace years=0 if service_years<=9
replace years=1 if service_years>=10 & service_years<=19
replace years=2 if service_years>=20 & service_years<=29
replace years=2 if service_years>=30 
label define years 0 "<10" 1 "10-19" 2 "20-29" 3 ">30"
label value years years
label var years "Teaching Age Range"

* Teacher gender 
gen gender1 = 0 if gender==1
replace gender1=1 if gender==2
label define gender1 0 "Male" 1 "Female"
drop gender
rename gender1 gender
label values gender gender
label var gender "Gender"

* Grade teacher teaches variable 
rename grade grade1
gen grade =.
replace grade=1 if ((m2saq7_98| m2saq7_1==1 | m2saq7_2==1 | m2saq7_3==1) & (m2saq7_4!=1 | m2saq7_5!=1 | m2saq7_6!=1 | m2saq7_7!=1))
replace grade=2 if (m2saq7_4==1 | m2saq7_5==1 | m2saq7_6==1 | m2saq7_7==1) & (m2saq7_98!=1 | m2saq7_1!=1 | m2saq7_2!=1 | m2saq7_3!=1)
replace grade=3 if (m2saq7_4==1 | m2saq7_5==1 | m2saq7_6==1 | m2saq7_7==1) & (m2saq7_98==1 | m2saq7_1==1 | m2saq7_2==1 | m2saq7_3==1)
replace grade=. if missing(m2saq7_98 | m2saq7_1 | m2saq7_2 | m2saq7_3 | m2saq7_4 | m2saq7_5 | m2saq7_6| m2saq7_7)
label define grade 1 "Lower Primary" 2 "Upper Primary" 3 "All Primary Grades", replace
label values grade grade
label var grade "Grade"
replace grade1=4 if grade1==.

* Teacher absent from teaching variable
gen absent = 0 if teacher_absent==1  | teacher_absent==3
replace absent = 1 if teacher_absent==2  | teacher_absent==4 | teacher_absent==5 | teacher_absent==6
replace absent=. if missing(teacher_absent)
label define absent 0 "Teaching" 1 "Not Teaching"
label value absent absent
label var absent "Presence - Teaching"

* Teacher absent from class variable
gen absent_class =0 if teacher_absent==1 | teacher_absent==2
replace absent_class=1 if teacher_absent==3 |teacher_absent==4 |teacher_absent==5 |teacher_absent==6 
replace absent_class=. if missing(teacher_absent)
label define absent_class 0 "In Class" 1 "Absent from Class", replace
label value absent_class absent_class
label var absent_class "Absent - Class"

* Teacher absent from school variable
gen absent_school=0 if teacher_absent==1 | teacher_absent==2 | teacher_absent==3 |teacher_absent==4 |teacher_absent==5
replace absent_school=1 if teacher_absent==6
label define absent_school 0 "At School" 1 "Absent from School", replace
replace absent_school=. if missing(teacher_absent)
label value absent_school absent_school
label var absent_school "Absent - School"

* Subject taught variable
rename subject subject1
gen subject=0 if m2saq8_1==1 & !missing(m2saq8_1)
replace subject=1 if m2saq8_2==1 & !missing(m2saq8_2)
replace subject=2 if m2saq8_3==1 & !missing(m2saq8_3)
replace subject=3 if m2saq8_97==1 & !missing(m2saq8_97)
label define subject 0 "Language" 1 "Mathematics" 2 "Both/All" 3 "Other", replace
label value subject subject
label var subject "Subject"

gen subject2=.
replace subject2=0 if subject1== "ENG" | subject1== "Eng" |subject1== "English"
replace subject2=1 if subject1=="Maths" | subject1== "Math" | subject1== "MATH"
label define subject2 0 "Language" 1 "Mathematics", replace
label value subject2 subject2
label var subject2 "Teach - Subject"
drop subject1
rename subject2 subject1

* Training / education level variable
gen edu_level1=.
replace edu_level1 = 1 if edu_level==3 & !missing(edu_level)
replace edu_level1 = 2 if edu_level==4 & !missing(edu_level)
replace edu_level1 = 3 if edu_level==5 & !missing(edu_level)
replace edu_level1 = 4 if edu_level==6 & !missing(edu_level)
replace edu_level1 = 5 if edu_level==7 & !missing(edu_level)
replace edu_level1 = 6 if edu_level==8 & !missing(edu_level)
replace edu_level1 = 7 if edu_level==97 & !missing(edu_level) 
label define edu_level1 1 "Primary" 2 "Lower Secondary" 3 "Upper Secondary" 4 "University - Bachelor" 5 "University - Master" 6 "University - Doctoral" 7 "Teaching Certificate"
label value edu_level1 edu_level1
label var edu_level1 "Highest Education Level"

gen trained1 = 0 if edu_level1 == 1 |edu_level1 == 2 |edu_level1 == 3
replace trained = 1 if edu_level1 == 4 |edu_level1 == 5 |edu_level1 == 6 |edu_level1 == 7
label define trained 0 "Untrained" 1 "Trained"
label value trained1 trained1
label var trained1 "Trained"

** Converting/creating variables to make running the analysis easier (teacher level - focus areas)

* Time spent on reading
rename m3saq7 reading

** Converting/creating variables to make running the analysis easier (teacher level - presence and practices)

* Missed school for a school-related reason
gen missed=0 
replace missed=1 if m3sbq1_tatt_1==1 | m3sbq1_tatt_2==1 | m3sbq1_tatt_3==1 | m3sbq1_tatt_97==1
replace missed=. if missing(m3sbq1_tatt_1) & missing(m3sbq1_tatt_2) & missing(m3sbq1_tatt_3) & missing(m3sbq1_tatt_97)
label define missed 0 "No" 1 "Yes"
label value missed missed
label var missed "Missed school"

* Opinion on discipline for teacher if absent 30% of time 
gen teacher_discipline=1 
replace teacher_discipline=0 if m3sbq2_tmna_7==1 & !missing(m3sbq2_tmna_7)
replace teacher_discipline=. if missing(m3sbq2_tmna_1) & missing(m3sbq2_tmna_2) & missing(m3sbq2_tmna_3) & missing(m3sbq2_tmna_4) & missing(m3sbq2_tmna_5) & missing(m3sbq2_tmna_6) & missing(m3sbq2_tmna_97)  & missing(m3sbq2_tmna_98)
label define teacher_discipline 0 "No Consequence" 1 "Consequence"
label value teacher_discipline teacher_discipline
label var teacher_discipline "Teacher opinion on teacher consequences if missing school"

* Teachers uses technology in classroom
rename m3sbq4_inpt tech

* How do teachers support students when they are struggling?
egen supportsum = rowtotal(m3sbq5_pedg_1 m3sbq5_pedg_2 m3sbq5_pedg_3 m3sbq5_pedg_4 m3sbq5_pedg_97)
gen support=0 
replace support=1 if m3sbq5_pedg_1==1 & m3sbq5_pedg_2!=1 & m3sbq5_pedg_3!=1 & m3sbq5_pedg_4!=1 & m3sbq5_pedg_97!=1
replace support=2 if m3sbq5_pedg_1!=1 & m3sbq5_pedg_2==1 & m3sbq5_pedg_3!=1 & m3sbq5_pedg_4!=1 & m3sbq5_pedg_97!=1
replace support=3 if m3sbq5_pedg_1!=1 & m3sbq5_pedg_2!=1 & m3sbq5_pedg_3==1 & m3sbq5_pedg_4!=1 & m3sbq5_pedg_97!=1
replace support=4 if m3sbq5_pedg_1!=1 & m3sbq5_pedg_2!=1 & m3sbq5_pedg_3!=1 & m3sbq5_pedg_4==1 & m3sbq5_pedg_97!=1
replace support=5 if m3sbq5_pedg_1!=1 & m3sbq5_pedg_2!=1 & m3sbq5_pedg_3!=1 & m3sbq5_pedg_4!=1 & m3sbq5_pedg_97==1
replace support=6 if supportsum>1
replace support=. if missing(m3sbq5_pedg_1) & missing(m3sbq5_pedg_2) & missing(m3sbq5_pedg_3) & missing(m3sbq5_pedg_4) & missing(m3sbq5_pedg_97)
label define support 1 "Group students by level" 2 "After school support" 3 "Computer adjusted  learning" 4 "Individual/target learning" 5 "Other" 6 "Multiple approaches", replace
label values support support 
label var support "Teacher support for children" 

* Formally evaluated
rename m3sbq6_tmna evaluated

** Converting/creating variables to make running the analysis easier (teacher level - opinions)

* Regarding teacher absenteeism (scale of 1-4)
rename m3scq1_tinm abs_complete_curr	
rename m3scq2_tinm abs_student_work
rename m3scq3_tinm abs_teacher_use	

* Regarding student attentiveness (scale of 1-4)
rename m3scq4_tinm	att_reg
rename m3scq5_tinm	att_prepared
rename m3scq6_tinm	att_mot

* Regarding student intelligent (scale of 1-4)
rename m3scq7_tinm	intelligent
rename m3scq10_tinm	change_intell_no
rename m3scq11_tinm	change_intell_always
rename m3scq14_tinm	change_intell_some

* Teacher motivation 
gen motivation1=.
replace motivation1=1 if m3scq15_tinm_1==1 & m3scq15_tinm_2!=1 & m3scq15_tinm_3!=1 & m3scq15_tinm_4!=1 & m3scq15_tinm_5!=1  
replace motivation1=2 if m3scq15_tinm_1!=1 & m3scq15_tinm_2==1 & m3scq15_tinm_3!=1 & m3scq15_tinm_4!=1 & m3scq15_tinm_5!=1  
replace motivation1=3 if m3scq15_tinm_1!=1 & m3scq15_tinm_2!=1 & m3scq15_tinm_3==1 & m3scq15_tinm_4!=1 & m3scq15_tinm_5!=1  
replace motivation1=4 if m3scq15_tinm_1!=1 & m3scq15_tinm_2!=1 & m3scq15_tinm_3!=1 & m3scq15_tinm_4==1 & m3scq15_tinm_5!=1  
replace motivation1=5 if m3scq15_tinm_1!=1 & m3scq15_tinm_2!=1 & m3scq15_tinm_3!=1 & m3scq15_tinm_4!=1 & m3scq15_tinm_5==1  
replace motivation1=. if missing(m3scq15_tinm_1) & missing(m3scq15_tinm_2) & missing(m3scq15_tinm_3) & missing(m3scq15_tinm_4) & missing(m3scq15_tinm_5)
label define motivation1 1 "Always wanted" 2 "I like teaching" 3 "Steady career path" 4 "Shape adolescents" 5 "Benefit socially disadvantaged", replace
label values motivation1 motivation1
label var motivation1 "Teacher primary motivation"

gen motivation2=.
replace motivation2=1 if m3scq15_tinm_1==2 & m3scq15_tinm_2!=2 & m3scq15_tinm_3!=2 & m3scq15_tinm_4!=2 & m3scq15_tinm_5!=2  
replace motivation2=2 if m3scq15_tinm_1!=2 & m3scq15_tinm_2==2 & m3scq15_tinm_3!=2 & m3scq15_tinm_4!=2 & m3scq15_tinm_5!=2  
replace motivation2=3 if m3scq15_tinm_1!=2 & m3scq15_tinm_2!=2 & m3scq15_tinm_3==2 & m3scq15_tinm_4!=2 & m3scq15_tinm_5!=2  
replace motivation2=4 if m3scq15_tinm_1!=2 & m3scq15_tinm_2!=2 & m3scq15_tinm_3!=2 & m3scq15_tinm_4==2 & m3scq15_tinm_5!=2  
replace motivation2=5 if m3scq15_tinm_1!=2 & m3scq15_tinm_2!=2 & m3scq15_tinm_3!=2 & m3scq15_tinm_4!=2 & m3scq15_tinm_5==2  
replace motivation2=. if missing(m3scq15_tinm_1) & missing(m3scq15_tinm_2) & missing(m3scq15_tinm_3) & missing(m3scq15_tinm_4) & missing(m3scq15_tinm_5)
label define motivation2 1 "Always wanted" 2 "I like teaching" 3 "Steady career path" 4 "Shape adolescents" 5 "Benefit socially disadvantaged", replace
label values motivation2 motivation2
label var motivation2 "Teacher secondary motivation"

gen motivation=.
replace motivation=1 if motivation1==1 |motivation1==2 | motivation2==1 | motivation2==2
replace motivation=2 if motivation1==4 |motivation1==5 | motivation2==4 | motivation2==5
replace motivation=3 if motivation1==3 | motivation2==3 
label define motivation 1 "Intrinsic" 2 "Altruistic" 3 "Extrinsic"
label values motivation motivation
label var motivation

** Converting/creating variables to make running the analysis easier (teacher level - recruitment and PD)

* Recruitment process 
gen recruitment=.
replace recruitment=0 if m3sdq1_tsdp_1==1
replace recruitment=1 if m3sdq1_tsdp_2==1
replace recruitment=2 if m3sdq1_tsdp_3==1 |m3sdq1_tsdp_4==1
replace recruitment=3 if m3sdq1_tsdp_5==1 
replace recruitment=4 if m3sdq1_tsdp_6==1
replace recruitment=5 if m3sdq1_tsdp_7==1
replace recruitment=6 if m3sdq1_tsdp_8==1
replace recruitment=7 if m3sdq1_tsdp_9==1
label define recruitment 0 "Completed course work" 1 "Educational Qualification " 2 "Graduated from Teritary Degree" 3 "Passed Subject Content Test" 4 "Passed Interview Assessment" 5 "Possessed Minimum Practical Professional Experience" 6 "Passed Assessment based on Practical Professional Experience" 7 "Based on Mock Class"
label values recruitment recruitment
label var recruitment

* Probationary period
rename m3sdq2_tmna probationary

* Participate in induction/mentorship program
rename  m3sdq3 induction

* Used skills used in induction/mentorship program
rename m3sdq4_tsup skills

**Types of skills used
gen skills_used=.
replace skills_used=0 if m3sdq5_tsup_1==1 & m3sdq5_tsup_2==1 & m3sdq5_tsup_6==1
replace skills_used=1 if m3sdq5_tsup_3==1 
replace skills_used=2 if m3sdq5_tsup_4==1 & m3sdq5_tsup_5==1 & m3sdq5_tsup_7==1 & m3sdq5_tsup_8==1
label define skills_used 0 "Classroom Management" 1 "Content Knowledge" 2 "Pedagogical Skills" 
label values skills_used skills_used
label var skills_used

* Required to have a teaching practicum as part of pre-service training
gen practicum=.
replace practicum=1 if m3sdq6_tsup==1
replace practicum=0 if m3sdq6_tsup==2
label define practicum 0 "No" 1 "Yes"
label value practicum practicum
label var practicum "Teacher had a practicum as part of pre-service training"

* Attend any in-service trainings in past 12 months
rename m3sdq9_tsup attended_training

* Number of days of trainings
gen training_days=.
replace training_days=0 if m3sdq10_tsup<=5
replace training_days=1 if m3sdq10_tsup>=6 & m3sdq10_tsup<=10
replace training_days=2 if m3sdq10_tsup>=11 & m3sdq10_tsup<=15
replace training_days=3 if m3sdq10_tsup>=16 & m3sdq10_tsup<=20
replace training_days=4 if m3sdq10_tsup>=21
label define training_days 0 "< 5" 1 "5-10" 2 "10-15" 3 "15-20" 4 "> 20"
label value training_days training_days
label var training_days "Number of days of training"

* Main topic training
gen training =.
replace training=0 if m3sdq12_tsup==1
replace training=1 if m3sdq12_tsup==2
replace training=2 if m3sdq12_tsup==3
replace training=3 if m3sdq12_tsup==4
replace training=4 if m3sdq12_tsup==5
replace training=5 if m3sdq12_tsup==6
replace training=6 if m3sdq12_tsup==7
label define training 0 "Lesson Planning" 1 "Increase Enrollment and Attendance" 2 "Content Knowledge" 3 "General Pedagogical Skills" 4 "Specific Pedagogical Skills" 5 "Classroom Management" 6 "Inclusive Education Pedagogy" 
label values training training
label var training

gen training_topic=.
replace training_topic=0 if m3sdq12_tsup==1 | m3sdq12_tsup==2 | m3sdq12_tsup==6
replace training_topic=1 if m3sdq12_tsup==3 
replace training_topic=2 if m3sdq12_tsup==4 | m3sdq12_tsup==5 | m3sdq12_tsup==7 | m3sdq12_tsup==8
label define training_topic 0 "Classroom Management" 1 "Content Knowledge" 2 "Pedagogical Skills" 
label values training_topic training_topic
label var training_topic

* Improve and Collaborate
rename m3sdq14_ildr improve

* Observed
rename m3sdq15_ildr observed

* Provided Feedback
rename m3sdq21_ildr observed_feedback

** Converting/creating variables to make running the analysis easier (teacher level - satisfaction and compensation)

* How satisfied are you with job (Scale 1-5)
rename m3seq1_tatt satisified_job	

* How satisfied are you with social status in community (Scale 1-5)
rename m3seq2_tatt satisfied_socialstatus

* Receive any bonsuses in past year?
rename m3seq4_tatt bonus

* Salary delay in last year?
rename m3seq6_tatt	salary_delay

** Gen Opinion on Progression **
gen progression=.
replace progression=0 if m3seq3_tatt==0
replace progression=1 if m3seq3_tatt==1

** Teach Variables **
rename s_a1 supportive_envir
rename s_a2 positive_beh
rename s_b3 lesson_facil
rename s_b4 checks_understanding
rename s_b5 feedback
rename s_b6 critical_thinking
rename s_c7 autonomy
rename s_c8 perseverance
rename s_c9 social_collab_skills

** Creating final variables for analysis
gen teacher_urban= cond(urban_rural==1 & government==0, 0, cond(urban_rural==1 & government==1,1,.))
gen teacher_rural= cond(urban_rural==0 & government==0, 0, cond(urban_rural==0 & government==1,1,.))

drop teacher_male // remove blank variable 

gen teacher_male= cond(gender==0 & government==0, 0, cond(gender==0 & government==1,1,.))
gen teacher_female= cond(gender==1 & government==0, 0, cond(gender==1 & government==1,1,.))

gen teacher_untrained= cond(trained1==0 & government==0, 0, cond(trained1==0 & government==1,1,.))
gen teacher_trained= cond(trained1==1 & government==0, 0, cond(trained1==1 & government==1,1,.))

** Setting strata and fixing with a single PSU
egen strata=group(district urban_rural)
list strata if strata==5
replace strata = 6 in 298 
list strata if strata==9
replace strata = 10 in 446/450

drop if sch_owner=="Private" // removing private schools as this analysis is only focused on public

** Keeping only the variables of interest for analysis
keep ipw hashed_school_code school_code school_name sch_owner district region urban_rural abs_weight_component teacher_weight_component g4_stud_weight_component g1_stud_weight_component teachers_id service_years edu_level1 trained1 government gender age grade subject edu_level fulltime grade1 subject1 teacher_absent  service_years training_days evaluated improve training_topic progression observed_feedback observed skills_used recruitment absent  abs_complete_curr abs_student_work abs_teacher_use att_reg att_prepared att_mot intelligent change_intell_no change_intell_always change_intell_some probationary induction skills practicum attended_training satisified_job satisfied_socialstatus bonus salary_delay literacy_content_knowledge math_content_knowledge motivation support missed teacher_discipline  supportive_envir positive_beh lesson_facil checks_understanding feedback critical_thinking autonomy perseverance social_collab_skills absent_class absent_school instruction socio_emotional_skills classroom_culture m2saq7_4 years training teacher_urban teacher_rural teacher_male teacher_female teacher_trained teacher_untrained strata

save "$cleandata/GEPD_final_analysis.dta", replace // final teacher level datasets

***************************************
* GEPD Student Assessment Dataset
***************************************

use "$cleandata/GEPD_final_analysis.dta"
drop if feedback==.
drop if grade1==2
duplicates report school_code
duplicates drop school_code, force
keep  ipw hashed_school_code school_code school_name sch_owner district region urban_rural abs_weight_component teacher_weight_component g4_stud_weight_component g1_stud_weight_component teachers_id service_years edu_level1 trained1 government gender age grade subject edu_level fulltime grade1 subject1 literacy_content_knowledge math_content_knowledge  supportive_envir positive_beh lesson_facil checks_understanding feedback critical_thinking autonomy perseverance social_collab_skills teacher_urban teacher_rural teacher_male teacher_female teacher_untrained teacher_trained
merge 1:m school_code using "$cleandata/GEPD_student.dta"

* Setting strata and fixing with a single PSU
egen strata=group(district urban_rural)
list strata if strata==5
replace strata = 6 in 298 
list strata if strata==9
replace strata = 10 in 446/450

drop if sch_owner=="Private" // removing private schools as this analysis is only focused on public

save "$cleandata/GEPD_final_analysis_students.dta", replace

***************************************
* Teach Datasets - Peers and adding to Sierra Leone level
***************************************
clear 

import excel using "$rawdata/Teach_peers.xlsx", sheet("Teach_descriptivesbycountry") firstrow clear

* Generate a new variable with unique identifiers for each country
egen country_id = group(group1)

* Drop the original country_name variable to ensure anonymity
drop group1
keep if vars == "Classroom Culture" | vars == "Instruction" | vars == "Socioemotional Skills"
keep vars mean country_id

save "$cleandata/teach_peers1.dta", replace

* Add in the Sierra Leone data 
clear 
use "$cleandata/GEPD_teacher_level.dta"

* Keep only the relevant variables
keep instruction classroom_culture socio_emotional_skills

* Collapse to get the means of the variables
collapse (mean) instruction classroom_culture socio_emotional_skills

* Create an identifier for the single observation
gen id = _n

* Reshape from wide to long format
rename instruction mean1
rename classroom_culture mean2
rename socio_emotional_skills mean3

reshape long mean, i(id) j(varnum)

* Create a variable to store the variable names
gen vars = ""
replace vars = "Instruction" if varnum == 1
replace vars = "Classroom Culture" if varnum == 2
replace vars = "Socioemotional Skills" if varnum == 3

* Rename and drop unnecessary variables
rename mean mean
drop id varnum

* Keep only the necessary columns
keep vars mean

* Generate country_id variable
gen country_id = 0

append using "$cleandata/teach_peers1.dta"
label define country_id 0 "Sierra Leone" 1 "Peer 1" 2 "Peer 2" 3 "Peer 3" 4 "Peer 4" 5 "Peer 5" 6 "Peer 6" 
label values country_id country_id

* Save the cleaned dataset
save "$cleandata/teach_peers.dta", replace
***************************************
* ASC Datasets
***************************************
clear 

** Creating dta files and appending years 2015-2022 together

* 2015 
import excel "$rawdata/2015 Teachers.xlsx", sheet("Query1") firstrow clear
drop year
gen year = 2015
rename School idemis_code

gen teacher_salary_source=.
replace teacher_salary_source=0 if Salary==1
replace teacher_salary_source=1 if Salary==2
replace teacher_salary_source=2 if Salary==3
replace teacher_salary_source=3 if Salary==4 | Salary==.
label define teacher_salary_source 0 "Government" 1 "Private" 2 "Households" 3 "Volunteer", replace
label values teacher_salary_source teacher_salary_source

tostring owner, replace
gen sch_owner=.
replace sch_owner=0 if owner=="4"
replace sch_owner=1 if owner=="1"
replace sch_owner=2 if owner=="3"
replace sch_owner=4 if owner=="2"
replace sch_owner=3 if owner=="5"
label define sch_owner 0 "Community" 1 "Government" 2 "Mission" 4 "Private" 3 "Other"
label values sch_owner sch_owner

keep year idemis_code sch_owner teacher_salary_source
save "$cleandata/2015_teacher.dta", replace

* 2017, there is no 2016 teacher file
import excel "$rawdata/2017 Teachers.xlsx", sheet("Teacher (4)") firstrow clear
gen year = 2017
rename school_num idemis_code

gen teacher_salary_source=.
replace teacher_salary_source=0 if Salary==1
replace teacher_salary_source=1 if Salary==2
replace teacher_salary_source=2 if Salary==3
replace teacher_salary_source=3 if Salary==4 | Salary==.
label define teacher_salary_source 0 "Government" 1 "Private" 2 "Households" 3 "Volunteer", replace
label values teacher_salary_source teacher_salary_source

gen sch_owner=.
replace sch_owner=0 if owner=="Community"
replace sch_owner=1 if owner=="Government"
replace sch_owner=2 if owner=="Mission"
replace sch_owner=4 if owner=="Private"
replace sch_owner=3 if owner=="Public"
label define sch_owner 0 "Community" 1 "Government" 2 "Mission" 4 "Private" 3 "Public"
label values sch_owner sch_owner

keep year idemis_code sch_owner teacher_salary_source
save "$cleandata/2017_teacher.dta", replace

* 2018
import excel "$rawdata/2018 School.xlsx", sheet("Annual School Census (EMIS_2018") firstrow clear
save "$cleandata/2018_school.dta", replace

import excel "$rawdata/2018 Teachers.xlsx", sheet("Annual School Census (EMIS_2018") firstrow clear
save "$cleandata/2018_teacher1.dta", replace

use "$cleandata/2018_teacher1.dta"
rename emis_code idemis_code 
rename school_type sch_type
rename region idregion
rename ward idward
rename district iddistrict
rename council_curr current_council 
rename town idtown 
rename school_name idschool_name
drop _merge
merge m:1 idemis_code idschool_name idtown sch_type using "$cleandata/2018_school.dta"
drop if _merge==1 | _merge==2
drop _merge
replace idemis_code = subinstr(idemis_code, "-", "",.)
gen year = 2018

rename teacher_salary_source Salary
gen teacher_salary_source=.
replace teacher_salary_source=0 if Salary=="Government"
replace teacher_salary_source=1 if Salary=="Private institution (firms, religious bodies, NGO)"
replace teacher_salary_source=2 if Salary=="Households (families, community)"
replace teacher_salary_source=3 if Salary=="Volunteer"
label define teacher_salary_source 0 "Government" 1 "Private" 2 "Households" 3 "Volunteer", replace
label values teacher_salary_source teacher_salary_source

rename sch_owner owner
gen sch_owner=.
replace sch_owner=0 if owner=="Community"
replace sch_owner=1 if owner=="Government"
replace sch_owner=2 if owner=="Mission"
replace sch_owner=4 if owner=="Private"
label define sch_owner 0 "Community" 1 "Government" 2 "Mission" 4 "Private" 
label values sch_owner sch_owner

keep year idemis_code sch_owner teacher_salary_source
save "$cleandata/2018_teacher.dta", replace

* 2019
import delimited "$rawdata/2019 Teachers.csv", clear 
gen year = 2019

rename teacher_salary_source Salary
gen teacher_salary_source=.
replace teacher_salary_source=0 if Salary=="Government"
replace teacher_salary_source=1 if Salary=="Private institution (firms, religious bodies, NGO)"
replace teacher_salary_source=2 if Salary=="Households (families, community)"
replace teacher_salary_source=3 if Salary=="Volunteer"
label define teacher_salary_source 0 "Government" 1 "Private" 2 "Households" 3 "Volunteer", replace
label values teacher_salary_source teacher_salary_source

rename sch_owner owner
gen sch_owner=.
replace sch_owner=0 if owner=="Community"
replace sch_owner=1 if owner=="Government"
replace sch_owner=2 if owner=="Mission/religious group"
replace sch_owner=4 if owner=="Private"
replace sch_owner=3 if owner=="Other"
label define sch_owner 0 "Community" 1 "Government" 2 "Mission" 4 "Private" 3 "Other"
label values sch_owner sch_owner

keep year idemis_code sch_owner teacher_salary_source
save "$cleandata/2019_teacher.dta", replace

* 2020
use "$rawdata/ASC2020 teachers.dta"
gen year = 2020

rename teacher_salary_source Salary
gen teacher_salary_source=.
replace teacher_salary_source=0 if Salary=="Government"
replace teacher_salary_source=1 if Salary=="Private institution (firms, religious bodies, NGO)"
replace teacher_salary_source=2 if Salary=="Households (families, communities, individual)"
replace teacher_salary_source=3 if Salary=="Volunteer"
label define teacher_salary_source 0 "Government" 1 "Private" 2 "Households" 3 "Volunteer", replace
label values teacher_salary_source teacher_salary_source

rename sch_owner owner
gen sch_owner=.
replace sch_owner=0 if owner=="Community"
replace sch_owner=1 if owner=="Government"
replace sch_owner=2 if owner=="Mission/religious group"
replace sch_owner=4 if owner=="Private"
replace sch_owner=3 if owner=="Other" 
label define sch_owner 0 "Community" 1 "Government" 2 "Mission" 4 "Private" 3 "Other"
label values sch_owner sch_owner

keep year idemis_code sch_owner teacher_salary_source
save "$cleandata/2020_teacher.dta", replace

* 2021 
import delimited "$rawdata/2021 Teachers.csv", clear
gen year = 2021
replace idemis_code = subinstr(idemis_code, "-", "",.)
keep year idemis_code sch_owner teacher_salary_source iddistrict
drop if iddistrict=="KOINADUGU"
save "$cleandata/2021_teacher1.dta", replace

import delimited "$rawdata/2021 Teacher_Koindugu.csv", encoding(UTF-8) clear 
gen year = 2021
replace idemis_code = subinstr(idemis_code, "-", "",.)
keep year idemis_code sch_owner teacher_salary_source
save "$cleandata/2021_teacher2.dta", replace

use "$cleandata/2021_teacher1.dta"
append using "$cleandata/2021_teacher2.dta"

rename teacher_salary_source Salary
gen teacher_salary_source=.
replace teacher_salary_source=0 if Salary=="Government"
replace teacher_salary_source=1 if Salary=="Private institution (firms, religious bodies, NGO)" | Salary=="Private institution (firms, religious bodies, NGO)00" | Salary=="Private institution (firms, religious bodies, NGO)000" 
replace teacher_salary_source=2 if Salary=="Households (families, communities, individual)"
replace teacher_salary_source=3 if Salary=="Volunteer" | Salary=="Volunteer5" | Salary=="0" | Salary=="6"
label define teacher_salary_source 0 "Government" 1 "Private" 2 "Households" 3 "Volunteer", replace
label values teacher_salary_source teacher_salary_source
replace teacher_salary_source=3 if teacher_salary_source==.

rename sch_owner owner
gen sch_owner=.
replace sch_owner=0 if owner=="Community"
replace sch_owner=1 if owner=="Government"
replace sch_owner=2 if owner=="Mission/religious group"
replace sch_owner=4 if owner=="Private"
replace sch_owner=3 if owner=="Other" 
label define sch_owner 0 "Community" 1 "Government" 2 "Mission" 4 "Private" 3 "Other"
label values sch_owner sch_owner
replace sch_owner=3 if sch_owner==.

keep year idemis_code sch_owner teacher_salary_source

save "$cleandata/2021_teacher.dta", replace

* 2022
import excel "$rawdata/2022 School.xlsx", sheet ("Annual School Census EMIS (2022") firstrow clear
save "$cleandata/2022_school.dta", replace

import excel "$rawdata/2022 Teachers.xlsx", sheet("teachers") firstrow clear
save "$cleandata/2022_teacher1.dta", replace

use "$cleandata/2022_school.dta"
rename KEY PARENT_KEY
merge 1:m PARENT_KEY using "$cleandata/2022_teacher1.dta"
drop if _merge==1 | _merge==2
drop _merge
replace idemis_code = subinstr(idemis_code, "-", "",.)
gen year = 2022
rename sch_type school_level

gen level=.
replace level=0 if school_level=="A. Pre- Primary"
replace level=1 if school_level=="B. Primary"
replace level=2 if school_level=="C. Junior Secondary"
replace level=3 if school_level=="D. Senior Secondary"
label define level 0 "Preprimary" 1 "Primary" 2 "JSS" 3 "SSS"
label values level level

gen district=.
replace district=0 if iddistrict=="BO"
replace district=1 if iddistrict=="BOMBALI"
replace district=2 if iddistrict=="BONTHE"
replace district=3 if iddistrict=="FALABA"
replace district=4 if iddistrict=="KAILAHUN"
replace district=5 if iddistrict=="KAMBIA"
replace district=6 if iddistrict=="KARENE"
replace district=7 if iddistrict=="KENEMA"
replace district=8 if iddistrict=="KOINADUGU"
replace district=9 if iddistrict=="KONO"
replace district=10 if iddistrict=="MOYAMBA"
replace district=11 if iddistrict=="PORT LOKO"
replace district=12 if iddistrict=="PUJEHUN"
replace district=13 if iddistrict=="TONKOLILI"
replace district=14 if iddistrict=="WESTERN AREA RURAL"
replace district=15 if iddistrict=="WESTERN AREA URBAN"
label define district 0 "BO" 1 "BOMBALI" 2 "BONTHE" 3 "FALABA" 4 "KAILAHUN" 5 "KAMBIA" 6 "KARENE"7 "KENEMA" 8 "KOINADUGU" 9 "KONO" 10 "MOYAMBA" 11 "PORT LOKO" 12 "PUJEHUN" 13 "TONKOLILI" 14 "WESTERN AREA RURAL" 15 "WESTERN AREA URBAN"
label values district district

rename teacher_salary_source Salary
gen teacher_salary_source=.
replace teacher_salary_source=0 if Salary==1
replace teacher_salary_source=1 if Salary==2
replace teacher_salary_source=2 if Salary==3
replace teacher_salary_source=3 if Salary==4
label define teacher_salary_source 0 "Government" 1 "Private" 2 "Households" 3 "Volunteer", replace
label values teacher_salary_source teacher_salary_source
replace teacher_salary_source=3 if teacher_salary_source==.

rename sch_owner owner
gen sch_owner=.
replace sch_owner=0 if owner=="Community"
replace sch_owner=1 if owner=="Government"
replace sch_owner=2 if owner=="Mission/religious group"
replace sch_owner=4 if owner=="Private"
replace sch_owner=3 if owner=="Other" 
label define sch_owner 0 "Community" 1 "Government" 2 "Mission" 4 "Private" 3 "Other"
label values sch_owner sch_owner
replace sch_owner=3 if sch_owner==.

keep year idemis_code sch_owner teacher_salary_source level district
save "$cleandata/2022_teacher.dta", replace

use "$cleandata/2022_teacher.dta"
append using "$cleandata/2021_teacher.dta"
append using "$cleandata/2020_teacher.dta"
append using "$cleandata/2019_teacher.dta" 
append using "$cleandata/2018_teacher.dta"
append using "$cleandata/2017_teacher.dta", force
append using "$cleandata/2015_teacher.dta", force

gen teacher_type =.
replace teacher_type= 1 if teacher_salary_source==0
replace teacher_type= 0 if teacher_salary_source==1 | teacher_salary_source==2 | teacher_salary_source==3
label define teacher_type 1 "Government" 0 "Contract"
 
drop if sch_owner == 4
drop if missing(teacher_type)

save "$cleandata_allyears.dta", replace
