********************************************************************************
*
*     A Comparative Analysis of Contract and Government  
* 	  Teachers in Sierra Leone: Profiles and Practices 
*
*     Stata .do file 1: Primary
*
********************************************************************************
    /*
    ** PURPOSE:      Supporting analysis of ASC and GEPD datasets in Sierra Leone 

    ** OUTLINE:      PART 1: Set globals for dynamic file paths and settings
                     PART 2: Call the task-specific do-files 

    ** WRITTEN BY:   Emma Cameron

    ** Last date modified:  May 22, 2024
    */

* ******************************************************************** *
*
*       PART 1:  Set globals for dynamic file paths and settings
*
* ******************************************************************** *

timer clear 1 
timer on 1

*** Only line 26 needs to be edited to define the users personal path 
global projectfolder       "C:/Users/wb614536/Documents/RR_SLE_2024_150/files submitted/version1/DEC Reproducibility Verification/projectfolder"

*** Set ado folder 
sysdir set PLUS "$projectfolder/datafolder/dofiles/ado"
*** Install all packages that this project requires
/*local packages 1

if `packages' {
ssc install labutil, 	replace
ssc install ietoolkit, 	replace
ssc install winsor, 	replace
ssc install sxpose, 	replace
ssc install dataout, 	replace
ssc install estout, 	replace
ssc install reghdfe, 	replace
ssc install unique, 	replace
ssc install tabout, 	replace
}
*/	   

global datafolder      	   "$projectfolder/datafolder"
global rawdata             "$datafolder/rawdata" 
global cleandata           "$datafolder/cleandata" 
global output              "$datafolder/output" 
global dofiles             "$datafolder/dofiles"

set varabbrev on


* ******************************************************************** *
*
*       PART 2: - Call the task-specific do-files
*
* ******************************************************************** *

*** PART 1: Clean and format data
* This do file cleans and runs through several different datasets. It cleans and merges the different teacher and school GEPD datasets, the student level assessment dataset, the teacher weights. It also merges the government's Annual School Census datasets for all years 2015-2022 (minus 2016 because there was no teacher dataset for this year)
do "$dofiles/clean.do"

*** PART 2: Run analysis
do "$dofiles/analysis.do"

timer off 1
timer list 1